# cc-init

<!--
[![build status](https://img.shields.io/travis/imcuttle/cc-init/master.svg?style=flat-square)](https://travis-ci.org/imcuttle/cc-init)
[![Test coverage](https://img.shields.io/codecov/c/github/imcuttle/cc-init.svg?style=flat-square)](https://codecov.io/github/imcuttle/cc-init?branch=master)
-->

[![NPM version](https://img.shields.io/npm/v/cc-init.svg?style=flat-square)](https://www.npmjs.com/package/cc-init)
[![NPM Downloads](https://img.shields.io/npm/dm/cc-init.svg?style=flat-square&maxAge=43200)](https://www.npmjs.com/package/cc-init)

Set commitlint & conventional-changelog quickly

## Why?

I need to write and install lots of works when I want to use [`commitlint`](https://github.com/marionebl/commitlint) with [`husky`](https://github.com/typicode/husky) and [`conventional-changelog`](https://github.com/conventional-changelog/conventional-changelog) for conventional changelog.

```json
{
  "scripts": {
    "version": "npm run changelog",
    "changelog": "conventional-changelog -p angular -i CHANGELOG.md -s -r 0 && git add CHANGELOG.md"
  },
  "husky": {
    "hooks": {
      "commit-msg": "commitlint -e $HUSKY_GIT_PARAMS"
    }
  },
  "commitlint": {
    "extends": ["@commitlint/config-conventional"]
  },
  "devDependencies": {
    "@commitlint/cli": "^7.1.1",
    "@commitlint/config-conventional": "^7.1.1",
    "conventional-changelog-cli": "^2.0.5",
    "husky": "^0.14.3"
  }
}
```

So the package can help you setting commitlint & conventional-changelog quickly.

## Usage

### CLI

```bash
npm install cc-init -g
# or use yarn
yarn global add cc-init
cc-init -h
```

### Package

```javascript
import ccInit from 'cc-init'
ccInit(cwd, {
  // ...options
})
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### cli

[bin.js:25-32](https://github.com/imcuttle/cc-init/blob/58a660e11b4c988b297986bc08351c0eb5cd1e57/bin.js#L25-L32 'Source code on GitHub')

```bash
export CHANGELOG_PRESET=@baidu/befe
export CHANGELOG_PRESET_PKGNAME=@baidu/conventional-changelog-befe
export NPM_REGISTRY=http://registry.npm.baidu-int.com
export COMMITLINT_PRESET=@baidu/commitlint-config-befe
# Preset the default values
cc-init
```

### ccInit

[index.js:33-141](https://github.com/imcuttle/cc-init/blob/58a660e11b4c988b297986bc08351c0eb5cd1e57/index.js#L33-L141 'Source code on GitHub')

make commitlint, husky and conventional-changelog getting along harmoniously together.

#### Parameters

- `cwd` {string} - the project's root path
- `opts` {{}}
  - `opts.changelogPresetPkgName` {string}
    the custom changelog preset package's name should be installed
    like `@scoped/conventional-changelog-foo` (optional, default `''`)
  - `opts.changelogPreset` {string}
    [conventional-changelog](https://github.com/conventional-changelog)'s preset
    like `@scoped/foo` (optional, default `'angular'`)
  - `opts.registry` {string} the npm's registry (optional, default `''`)
  - `opts.commitlintPreset` {string}
    the [commitlint](https://github.com/marionebl/commitlint)'s preset config (optional, default `'@commitlint/config-conventional'`)
  - `opts.force` {boolean} - overwrite the existed config and devDependencies in `package.json`
  - `opts.stdio` {string}
    the [stdio](https://nodejs.org/dist/latest-v7.x/docs/api/child_process.html#child_process_options_stdio) of npm install process (optional, default `'inherit'`)

Returns **void**

## License

MIT
